==> haskell-optics-th-0.4.1-81-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optics-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 optics-th
version:              0.4.1
visibility:           public
id:                   optics-th-0.4.1-BcQBDZ8oIVZIMMavogWrX6
key:                  optics-th-0.4.1-BcQBDZ8oIVZIMMavogWrX6
license:              BSD-3-Clause
maintainer:           optics@well-typed.com
author:               Andrzej Rybczak
synopsis:             Optics construction using TemplateHaskell
description:
    This package is part of the @<https://hackage.haskell.org/package/optics optics>@
    package family.  It provides machinery to construct optics using @TemplateHaskell@.

    See the @template-haskell-optics@ package for optics to work with @template-haskell@ types.

category:             Data, Optics, Lenses
abi:                  0a26a478a45f935a54ed7320a3433e3f
exposed:              True
exposed-modules:
    Optics.TH Optics.TH.Internal.Product Optics.TH.Internal.Sum
    Optics.TH.Internal.Utils

hidden-modules:       Language.Haskell.TH.Optics.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/optics-th-0.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/optics-th-0.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/optics-th-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optics-th
hs-libraries:         HSoptics-th-0.4.1-BcQBDZ8oIVZIMMavogWrX6
depends:
    base-4.17.2.1 containers-0.6.7 mtl-2.2.2
    optics-core-0.4.1.1-I84GcFSVHcrGzq2nETAKS5
    template-haskell-2.19.0.0
    th-abstraction-0.4.5.0-EtQVnbIEkAX5f6KN9Uwjhw transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-optics-th/html/optics-th.haddock
haddock-html:         /usr/share/doc/haskell-optics-th/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optics-th-0.4.1-82-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optics-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 optics-th
version:              0.4.1
visibility:           public
id:                   optics-th-0.4.1-6BtdmlQrKXl4kwtu089xKi
key:                  optics-th-0.4.1-6BtdmlQrKXl4kwtu089xKi
license:              BSD-3-Clause
maintainer:           optics@well-typed.com
author:               Andrzej Rybczak
synopsis:             Optics construction using TemplateHaskell
description:
    This package is part of the @<https://hackage.haskell.org/package/optics optics>@
    package family.  It provides machinery to construct optics using @TemplateHaskell@.

    See the @template-haskell-optics@ package for optics to work with @template-haskell@ types.

category:             Data, Optics, Lenses
abi:                  f0bfdadeecf383cf6fba463084f9ffe1
exposed:              True
exposed-modules:
    Optics.TH Optics.TH.Internal.Product Optics.TH.Internal.Sum
    Optics.TH.Internal.Utils

hidden-modules:       Language.Haskell.TH.Optics.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/optics-th-0.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/optics-th-0.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/optics-th-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optics-th
hs-libraries:         HSoptics-th-0.4.1-6BtdmlQrKXl4kwtu089xKi
depends:
    base-4.17.2.1 containers-0.6.7 mtl-2.2.2
    optics-core-0.4.1.1-HmNwCVIsyAG7ENSOVWq0i5
    template-haskell-2.19.0.0
    th-abstraction-0.4.5.0-EtQVnbIEkAX5f6KN9Uwjhw transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-optics-th/html/optics-th.haddock
haddock-html:         /usr/share/doc/haskell-optics-th/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
